@@ -1,6 +1,6 @@
 from concurrent.futures import ThreadPoolExecutor
 from pathlib import Path
-from typing import Any, Dict, Sequence
+from typing import Any, Dict, Sequence, Set
 
 from rich.progress import Progress, BarColumn
 
@@ -115,6 +115,7 @@ class HTMLBuilder(Builder):
         extensions_used: Set[Extension] = set()
         chunks = self.parse_file(source_file_path, extensions_used)
         if not chunks:
+            # TODO warn that the page is empty, and therefore nothing is written
             return
         css = self.core.get_css(self.extensions_used)
         html = self._transform_page_to_html(
@@ -185,6 +186,7 @@ class HTMLBuilder(Builder):
             )
             return
         if len(jobs) == 1:
+            print("1")
             with Progress(transient=True) as progress:
                 progress.add_task("[orange]Building 1 page", start=False)
                 self._process_file(
@@ -194,6 +196,7 @@ class HTMLBuilder(Builder):
                 )
         else:
             with ThreadPoolExecutor() as e:
+                print("2")
                 with Progress(
                     "[progress.description]{task.description}",
                     BarColumn(),
