@@ -7,6 +7,7 @@ from typing import Any, Dict, List, Optional, Sequence, Set, Tuple
 import rich
 from rich.tree import Tree
 import yaml
+from yaml.scanner import ScannerError
 
 from .chunks import (
     Chunk,
@@ -124,29 +125,29 @@ class Core:
                     raw, tag, page_variables, report, used_extensions=used_extensions
                 )
         elif chunk_type == RawChunkType.YAML:
-            temp: Any = yaml.safe_load("".join(raw.lines))
-            if isinstance(temp, dict):
-                dictionary: Dict[str, Any] = temp
-                if "type" in dictionary:
-                    return self.yaml_extension_point.cast_yaml(
-                        raw,
-                        dictionary["type"],
-                        dictionary,
-                        page_variables,
-                        used_extensions=used_extensions,
-                    )
-                else:
-                    data_chunk = YAMLDataChunk(raw, dictionary, page_variables)
-                    try:
-                        page_variables.update(data_chunk.dictionary)
-                    except ValueError as e:
-                        print(e)
-                    return data_chunk
+            try:
+                temp: Any = yaml.safe_load("".join(raw.lines))
+                if isinstance(temp, dict):
+                    dictionary: Dict[str, Any] = temp
+                    if "type" in dictionary:
+                        return self.yaml_extension_point.cast_yaml(
+                            raw,
+                            dictionary["type"],
+                            dictionary,
+                            page_variables,
+                            used_extensions=used_extensions,
+                        )
+                    else:
+                        data_chunk = YAMLDataChunk(raw, dictionary, page_variables)
+                        try:
+                            page_variables.update(data_chunk.dictionary)
+                        except ValueError as e:
+                            print(e)
+                        return data_chunk
+            except ScannerError as se:
+                raw.report.error(f"Something is wrong with YAML section {se}")
             else:
-                raw.tell(
-                    "Something is wrong with the YAML section.",
-                    level=Report.ERROR,
-                )
+                raw.report.error("Something is wrong with the YAML section.")
         elif chunk_type == RawChunkType.HTML:
             return HTMLChunk(raw, page_variables)
         elif chunk_type == RawChunkType.CODE:
